Multiple Scrolling Areas Example
===============================================================================

:download:`multi_scroll_area.enaml <../../../examples/advanced/multi_scroll_area.enaml>`

.. literalinclude:: ../../../examples/advanced/multi_scroll_area.enaml
    :language: python

::

 $ enaml-run multi_scroll_area.enaml

.. image:: images/multi_scroll_area.png
